# Gaze 智能视频云服务

Gaze 实时视频分析服务平台整合私有云的计算能力和物联网设备(如摄像头)的数据，在端(Edge)提供可扩展、可伸缩的视频分析能力。

# 简介
摄像头在当今社会中无处不在，无时无刻不在收集大量数据。然而这些数据就像“暗物质”，蕴含的知识，无人知晓；庞大的价值，并未充分发掘。

鉴于此，我们提出 Gaze 来整合私有云的计算能力和物联网设备(如摄像头)的数据。在端(Edge)提供可扩展、可伸缩的视频分析能力。

# 系统架构

![image](https://github.com/foamliu/Gaze/raw/master/images/architecture.svg?sanitize=true)

# 数据流图

![image](https://github.com/foamliu/Gaze/raw/master/images/dataflow.svg?sanitize=true)

# 快速上手

```bash
$ python demo.py
```


